/*
 * hy_protocol.h
 *
 *  Created on: 20241011
 *      Author: psx
 */

#ifndef APP_INC_HY_PROTOCOL_H_
#define APP_INC_HY_PROTOCOL_H_

#include "debug.h"
#include "uart_dev.h"
#include "math.h"

/*  */
typedef enum
{
    HY_batteryStatus                            = 0x60, /* ״̬ݱ */
    HY_electricityStatistics                    = 0x61, /* ͳݱ */
    HY_sensorNumberConfiguration                = 0x62, /*  */
    HY_sensorNumberInquiry                      = 0x63, /* ѯ */
    HY_chargingThresholdVoltageConfiguration    = 0x64, /* ֵѹ */
    HY_chargingRangeVoltageQuery                = 0x65, /* ֵѹѯ */
    HY_resetInstruction                         = 0x66, /* λָ */

    HY_chargingControlConfiguration             = 0x6C, /*  */
    HY_chargingControlQuery                     = 0x6D, /* Ʋѯ */

    HY_configureProtocolType                    = 0x70, /* Э */
    HY_responseConfigureProtocolType            = 0x71, /* ӦЭ */

    HY_queryControlBoxConfiguration             = 0x74, /* ѯؿƺеǰ */
    HY_querySoftwareVersion                     = 0x75, /* ѯؿƺ汾 */
    HY_enterConfigurationMode                   = 0x76, /* ģʽ */

    HY_configureHardwareID                      = 0x7B, /* ÿƺӲID */
    HY_hardwareID_communicationIDQuery          = 0x7C, /* ƺӲIDżͨIDţԭţѯ */
    HY_modifyCommunicationID                    = 0x7D, /* ޸ͨIDţԭţ */
    HY_checkMotherboardTemperature              = 0x7E, /* ѯ¶ֵ */

}HY_MsgFunctionCode;


/* ݰĳ */
typedef enum
{
    HY_analyzeStartFlag        = 1,  /* Ϊ1ʱʼ־ */
    HY_analyzeHardwareID       = 7,  /* Ϊ7ʱӲID */
    HY_analyzeCommunicationID  = 11, /* Ϊ10ʱͨID */
    HY_analyzeControlWord      = 12, /* Ϊ12ʱ */
    HY_analyzeDataLen          = 14, /* Ϊ14ʱݳ */

}HY_AnalyzeDataLen;



/* ָ뷽ʽΪ1ֽ */
#pragma pack(push,1)

/* Ĭϲ */
typedef struct _HY_default_Value{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t end_Flag;                       /* ־ */
}HY_default_Value;

extern HY_default_Value HY_defaultValue;

/* Ĭϲ */
typedef struct _HY_Recv_pack{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
}HY_Recv_pack;

/* 봦 */
typedef void (*HYMsgProcFunc)(device_handle device, void*, uint32_t MsgLen);
typedef struct _HY_FunctionMsgProcTable{
    u_int32_t    msgId;
    HYMsgProcFunc  pMsgProc;
}HY_FuncionMsgProcTable;


/* ״̬ݱѯ */
typedef struct _HY_batteryStatusQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_batteryStatusQuery;
#define HY_batteryStatusQuery_PACK_SIZE (sizeof(HY_batteryStatusQuery))

/* ״̬ݱӦ */
typedef struct _HY_batteryStatusResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    float_t batteryVoltage;                 /* صѹ */
    float_t dischargCurrent;                /* أ */
    float_t chargCurrent1;                  /* +أ */
    float_t SOC;                            /* ʣ */
    float_t openCircuitVoltage1;            /* 翪·ѹ */
    uint8_t chargSwitchStatus1;             /* 翪״̬ */
    float_t chargCurrent2;                  /* +أ */
    float_t openCircuitVoltage2;            /* 翪·ѹ */
    uint8_t chargSwitchStatus2;             /* 翪״̬ */
    float_t Mos_Temperature;                /* ¶ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_batteryStatusResponse;
#define HY_batteryStatusResponse_PACK_SIZE (sizeof(HY_batteryStatusResponse))

/* ͳݱѯ */
typedef struct _HY_electricityStatisticsQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_electricityStatisticsQuery;
#define HY_electricityStatisticsQuery_PACK_SIZE (sizeof(HY_electricityStatisticsQuery))

/* ״̬ݱӦ */
typedef struct _HY_electricityStatisticsResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    float_t statisticalDuration;            /* ͳʱ */
    float_t totalElectricityConsumption;    /* ܵ */
    float_t totalChargCapacity;             /* ܳ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_electricityStatisticsResponse;
#define HY_electricityStatisticsResponse_PACK_SIZE (sizeof(HY_electricityStatisticsResponse))

/*  */
typedef struct _HY_sensorNumberConfig{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t newHardwareID[6];               /* ӲIDֽǰֽں󣨱ֲ䣩 */
    uint8_t newCommunicationID[4];          /* ͨIDֽǰֽں */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_sensorNumberConfig;
#define HY_sensorNumberConfiguration_PACK_SIZE (sizeof(HY_sensorNumberConfig))

/* Ӧ */
typedef struct _HY_sensorNumberConfigurationResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_sensorNumberConfigurationResponse;
#define HY_sensorNumberConfigurationResponse_PACK_SIZE (sizeof(HY_sensorNumberConfigurationResponse))

/* ѯ */
typedef struct _HY_sensorNumberInquiryQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t broadcastTerminal[6];           /* 㲥նID:0xFF 0xFF 0xFF 0xFF 0xFF 0xFF */
    uint8_t broadcastCommunication[4];      /* 㲥ͨID:0xFF 0xFF 0xFF 0xFF */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_sensorNumberInquiryQuery;
#define HY_sensorNumberInquiryQuery_PACK_SIZE (sizeof(HY_sensorNumberInquiryQuery))

/* ѯӦ */
typedef struct _HY_sensorNumberInquiryResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t hardwareIDR[6];                 /* ӲIDֽǰֽں */
    uint8_t communicationIDR[4];            /* ͨIDֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_sensorNumberInquiryResponse;
#define HY_sensorNumberInquiryResponse_PACK_SIZE (sizeof(HY_sensorNumberInquiryResponse))

/* ֵѹ */
typedef struct _HY_chargingThresholdVoltageConfig{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    float_t chargOpenVoltage;               /* 翪صѹ */
    float_t chargCloseVoltage;              /* صصѹ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_chargingThresholdVoltageConfig;
#define HY_chargingThresholdVoltageConfig_PACK_SIZE (sizeof(HY_chargingThresholdVoltageConfig))

/* ֵѹӦ */
typedef struct _HY_chargingThresholdVoltageConfigResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_chargingThresholdVoltageConfigResponse;
#define HY_chargingThresholdVoltageConfigResponse_PACK_SIZE (sizeof(HY_chargingThresholdVoltageConfigResponse))


/* ֵѹѯ */
typedef struct _HY_chargRangeVoltageQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_chargRangeVoltageQuery;
#define HY_chargRangeVoltageQuery_PACK_SIZE (sizeof(HY_chargRangeVoltageQuery))

/* ֵѹѯӦ */
typedef struct _HY_chargRangeVoltageQueryResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    float_t chargOpenVoltage;               /* 翪صѹ */
    float_t chargCloseVoltage;              /* صصѹ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_chargRangeVoltageQueryResponse;
#define HY_chargRangeVoltageQueryResponse_PACK_SIZE (sizeof(HY_chargRangeVoltageQueryResponse))

/* λָ */
typedef struct _HY_resetInstructionQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_resetInstructionQuery;
#define HY_resetInstructionQuery_PACK_SIZE (sizeof(HY_resetInstructionQuery))

/* λָӦ */
typedef struct _HY_resetInstructionResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_resetInstructionResponse;
#define HY_resetInstructionResponse_PACK_SIZE (sizeof(HY_resetInstructionResponse))

/*  */
typedef struct _HY_chargingControlConfig{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t chargInterface;                 /* ӿ */
    uint8_t chargInterfaceControl;          /* ӿڿ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_chargingControlConfig;
#define HY_chargingControlConfig_PACK_SIZE (sizeof(HY_chargingControlConfig))

/* Ӧ */
typedef struct _HY_chargingControlConfigResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_chargingControlConfigResponse;
#define HY_chargingControlConfigResponse_PACK_SIZE (sizeof(HY_chargingControlConfigResponse))

/* Ʋѯ */
typedef struct _HY_QueryChargingControl{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_QueryChargingControl;
#define HY_QueryChargingControl_PACK_SIZE (sizeof(HY_QueryChargingControl))

/* ƲѯӦ */
typedef struct _HY_QueryChargingControlResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t chargInterface;                 /* ӿ״̬ */
    uint8_t chargInterfaceControl;          /* ӿ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_QueryChargingControlResponse;
#define HY_QueryChargingControlResponse_PACK_SIZE (sizeof(HY_QueryChargingControlResponse))

/* Э */
typedef struct _HY_configProtocolType{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t protocolType;                   /* Э;  0x01ʾԴЭ(9600) 0x02ʾЭ(115200)*/
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_configProtocolType;
#define HY_configProtocolType_PACK_SIZE (sizeof(HY_configProtocolType))

/* ЭӦ */
typedef struct _HY_configProtocolTypeResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_configProtocolTypeResponse;
#define HY_configProtocolTypeResponse_PACK_SIZE (sizeof(HY_configProtocolTypeResponse))

/* ѯؿƺеǰ */
typedef struct _HY_queryControlBoxConfigurationQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_queryControlBoxConfigurationQuery;
#define HY_queryControlBoxConfigurationQuery_PACK_SIZE (sizeof(HY_queryControlBoxConfigurationQuery))

/* ѯؿƺеǰӦ */
typedef struct _HY_queryControlBoxConfigurationResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t protocolType;                   /* Э;  0x01ʾԴЭ(9600) 0x02ʾЭ(115200)*/
    uint8_t voltageLevel;                   /* ѹȼ */
    uint8_t mainBoardTemperatureSensorType; /* ¶ȴ */
    uint8_t batteryTemperatureSensorType;   /* ¶ȴ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_queryControlBoxConfigurationResponse;
#define HY_queryControlBoxConfigurationResponse_PACK_SIZE (sizeof(HY_queryControlBoxConfigurationResponse))

/* ѯؿƺ汾 */
typedef struct _HY_SoftwareVersionQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_SoftwareVersionQuery;
#define HY_SoftwareVersionQuery_PACK_SIZE (sizeof(HY_SoftwareVersionQuery))

/* ѯؿƺ汾 */
typedef struct _HY_SoftwareVersionQueryResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t versionInformation[13];         /* 汾Ϣ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_SoftwareVersionQueryResponse;
#define HY_SoftwareVersionQueryResponse_PACK_SIZE (sizeof(HY_SoftwareVersionQueryResponse))

/* ģʽ */
typedef struct _HY_enterConfigMode{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_enterConfigMode;
#define HY_enterConfigMode_PACK_SIZE (sizeof(HY_enterConfigMode))

/* ģʽӦ */
typedef struct _HY_enterConfigModeResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_enterConfigModeResponse;
#define HY_enterConfigModeResponse_PACK_SIZE (sizeof(HY_enterConfigModeResponse))

/* ÿƺӲID */
typedef struct _HY_configHardwareID{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t newHardwareID[6];               /* ӲIDֽǰֽں */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_configHardwareID;
#define HY_configHardwareID_PACK_SIZE (sizeof(HY_configHardwareID))

/* ÿƺӲID Ӧ*/
typedef struct _HY_configHardwareIDResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_configHardwareIDResponse;
#define HY_configHardwareIDResponse_PACK_SIZE (sizeof(HY_configHardwareIDResponse))

///* ƺӲIDżͨIDţԭţѯ */
//typedef struct _HY_QueryhardwareID_communicationID{
//    uint8_t start_Flag;                     /* ʼ־  */
//    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
//    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
//    uint8_t controlWord;                    /*  */
//    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
//    uint32_t frameNumber;                   /* ֡ */
//    uint8_t check_Bit;                      /* У */
//    uint8_t end_Flag;                       /* ־ */
//}HY_QueryhardwareID_communicationID;
//#define HY_QueryhardwareID_communicationID_PACK_SIZE (sizeof(HY_QueryhardwareID_communicationID))

/* ޸ͨIDţԭţ */
typedef struct _HY_modifyCommunicationIDChange{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t nowHardwareID[6];               /* ӲIDֽǰֽں */
    uint8_t newcommunicationID[4];          /* ͨIDֽǰֽں */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_modifyCommunicationIDChange;
#define HY_modifyCommunicationIDChange_PACK_SIZE (sizeof(HY_modifyCommunicationIDChange))

/* ޸ͨIDţԭţӦ */
typedef struct _HY_modifyCommunicationIDChangeResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint8_t state;                          /* ״̬ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_modifyCommunicationIDChangeResponse;
#define HY_modifyCommunicationIDChangeResponse_PACK_SIZE (sizeof(HY_modifyCommunicationIDChangeResponse))

/* ѯ¶ֵ */
typedef struct _HY_checkMotherboardTemperatureQuery{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_checkMotherboardTemperatureQuery;
#define HY_checkMotherboardTemperatureQuery_PACK_SIZE (sizeof(HY_checkMotherboardTemperatureQuery))

/* ѯ¶ֵӦ */
typedef struct _HY_checkMotherboardTemperatureResponse{
    uint8_t start_Flag;                     /* ʼ־  */
    uint8_t hardwareID[6];                  /* ӲIDֽǰֽں */
    uint8_t communicationID[4];             /* ͨIDֽǰֽں */
    uint8_t controlWord;                    /*  */
    uint8_t dataLen[2];                     /* ݳȣֽǰֽں */
    float_t MotherboardTemperature;         /* ¶ */
    uint32_t frameNumber;                   /* ֡ */
    uint8_t check_Bit;                      /* У */
    uint8_t end_Flag;                       /* ־ */
}HY_checkMotherboardTemperatureResponse;
#define HY_checkMotherboardTemperatureResponse_PACK_SIZE (sizeof(HY_checkMotherboardTemperatureResponse))




/* ָĬϵĶ */
#pragma pack(pop)


uint8_t HY_CheckFunc(uint8_t *arr_buff, uint8_t len);
void HY_read_and_process_uart_data(device_handle device);



#endif /* APP_INC_HY_PROTOCOL_H_ */
